#!/usr/bin/perl -w


################################################################################
#-------------------------------------------------------------------------------
#  NAME:         displayResults.pl
# 
#  TYPE:         perl Script 
#
#  DESCRIPTION:  Outputs the status of the system's progress.  When finished, a 
#                link is created directing towards the simulation output files.
#                
#  DEPENDENCES:  getLogFile.pm     
#     
#  INPUTS:       N/A
#      
#  OUTPUTS:      N/A
#
#  HISTORY:
# 
#-------------------------------------------------------------------------------
################################################################################


# SET FOR USAGE WITH THE CGI-BIN
use CGI;
use CGI::Carp qw(warningsToBrowser fatalsToBrowser); 
use CGI qw(:standard);
  
# RETRIEVE A SET OF FUNCTIONS USED TO READ AND WRITE TO 
# LOG FILES
require "getLogFile.pm";


################################
# RETRIEVE AND DEFINE THE
# INITIAL INPUT VARIABLES
################################

# RETRIEVE THE WEB-SERVER OUTPUT/DISPLAY DIRECTORY
my $sate_puff_dir = getDispDir();

# DEFINE THE DIRECTORY WHERE THE RESULTS ARE LOCATED
my $results_dir = $sate_puff_dir.'/processedRuns';

# DEFINE THE WEB-BASED SYSTEM OUTPUT DIRECTORY
my $web_dir = getWebOutputDir();
my $web_results_dir="http://satepsanone.nesdis.noaa.gov/$web_dir/processedRuns";

# RETRIEVE DATA FROM THE 'GET'
my $processNum = param("processNum");

# GET THE PROFILE PLOT
my $heightProfile = "$results_dir/${processNum}_heightProfile.png" ;
#print "Height Profile:   $heightProfile";
#print " \n\n";

# INITIALIZE ARRAYS
my @fNames = ();
my @fProcess = ();
my @volcano = ();
my @height = ();
my @order = ();
my @tNames = ();

# GET A DIRECTORY LISTING FOR THE IMAGE OUTPUT DIRECTORY
my $counter = 0;
my @files = < $results_dir/${processNum}_sim_*.png>;
foreach $file (@files) {
   
    # GET THE FILENAME FROM THE FULL PATH NAME
    my @fullName = split('/',$file);
    my $fName = $fullName[$#fullName];
    push(@fNames, $fName);
    
    # EXTRACT INFORMATION FROM THE FILENAME
    my @fileInfo = split('_',$fName);
    
    # EXTRACT OUT THE PROCESSING NUMBER
    push(@fProcess, $fileInfo[0]);
    
    # EXTRACT OUT THE VOLCANO NAME
    push(@volcano, $fileInfo[2]);
    
    # EXTRACT OUT THE NUMERICAL HEIGHT
    my @fHeight = split('km',$fileInfo[3]);
    push(@height, $fHeight[0]);

    # KEEP TRACK OF THE INDEX ORDER
    push(@order, $counter);
    $counter++;
} 

# SAVE THE ARRAY LENGTH
my $arrayLen = $counter;

# GET A DIRECTORY LISTING FOR THE IMAGE OUTPUT THUMBNAILS
my @files = < $results_dir/${processNum}_simThumb_*.png>;
foreach $file (@files) {
   
    # GET THE FILENAME FROM THE FULL PATH NAME
    my @fullName = split('/',$file);
    my $fName = $fullName[$#fullName];
    push(@tNames, $fName);
} 


# GET A SORTED ARRAY INDEX, BASED ON THE HEIGHT (lowest -> highest)
my @sortedHeight = sort(@height);
my @sortedfNames = sort(@fNames);
my @sortedtNames = sort(@tNames);


# PRINT OUT THE WEBSITE INITIAL INFO
print "Content-type: text/html\n\n";

print "<html>";
print "<head></head>";
print "<body>";

print "<center>";
print "<table border=1>";
print "<tr><td align=center>";

# PRINT OUT THE HEIGHT PROFILE
print "<img src=$web_results_dir/$processNum"."_heightProfile.png ></img>";
print "</td> </tr>";

# PRINT OUT THE SIMULATION THUMBNAILS
print "<tr> <td>";

# COMPUTE THE TOTAL NUMBER OF ROWS AND COLUMNS TO BE IN OUR TABLE
my $nCols = 5;
$nCols = $nCols-1;
my $nImages = $arrayLen + 1;
my $nRows = int($nImages / $nCols)+1;

# PRINT OUT THE TABLE
print "<center>";
print "<table border=1>";
print "<br> <br>";
print "<b> PUFF Simulations </b>";

# ITERATE THROUGH EACH OF THE TABLE ELEMENTS TO BE WRITTEN
$counter=0;
for ($i=0; $i<=$nRows; $i++)
{
	print "<tr>";
	for ($j=0; $j<=$nCols; $j++)
	{
		print "<td>";	
	
		if ($counter < $nImages-1)
		{
		    # PRINT OUT THE HEIGHT
		    print "$sortedHeight[$counter] km <br>";
		    
		    # CREATE A LINK TO THE SIMULATION IMAGE
		    print "<a href=showSim.pl?processNum=$processNum&height=$sortedHeight[$counter]>";

		    # PRINT AN IMAGE THUMBNAIL OF THE SIMULATION
		    print "<img src=$web_results_dir/$sortedtNames[$counter]></img>";
		    print "</a>";

		    $counter++;
		}
		print "</td>";
	    }    
	print "</tr>";	
}


# FINISH PRINTING OUT THE TABLE 
print "</table>";
print "</center>";
print "</td> </tr>";
print "</table>";

# FINISH PRINTING OUT THE HTML PAGE ELEMENTS
print "</body>";
print "</html>";




