#!/usr/bin/perl -w

################################################################################
#-------------------------------------------------------------------------------
#  NAME:         getAllParameters.pl
#
#  TYPE:         perl Script
#
#  DESCRIPTION:  Produce a html file used to retrieve eruption/observations
#                parameters from the user.
#
#  DEPENDENCES:  getLogFile.pm
#                getLastDay.pl
#               
#  INPUTS:       RETRIEVED FROMT THE 'POST':
#                uName:   Login username
#                uPass:   Login password
#
#  OUTPUTS:      PUT IN THE 'POST':
#                $volcano:         Name for volcano that erupted
#                $erupt_year:      Year of the eruption
#
#                $erupt_month:     Month of the eruption
#                $erupt_day:       Day of the eruption
#                $erupt_hour:      Hour of the eruption
#                $erupt_min:       Minute of the eruption 
#                $erupt_duration:  The duration of the eruption
#                $sensor:          Sensor data being used 
#                $orbit_number     Satellite data orbital number 
#                $product          Type of product being used  
#                $obs_year         Observation year 
#                $obs_month        Observation month 
#                $obs_day          Observation day 
#                $obs_hour         Observation hour              
#                $obs_min          Observation minute 
#                $duCtOff          Threshold cut-off value for satellite data 
#    
#  HISTORY:
#
#  
#-------------------------------------------------------------------------------
################################################################################


# SET FOR USAGE WITH THE CGI-BIN
use CGI;

# SET TO DISPLAY ERROR INFORMATION WHEN AN ERROR OCCURS. OTHERWISE, A
#   A STANDARD ERROR MESSAGE WILL BE USED
use CGI::Carp qw(warningsToBrowser fatalsToBrowser); 
use CGI qw(:standard);

# PRINT OUT HTML HEADER INFORMATION
print "Content-type: text/html\n\n";

# RETRIEVE A SET OF FUNCTIONS USED TO READ AND WRITE TO 
# LOG FILES
require "getLogFile.pm";


################################
# FIRST, MAKE SURE THE ENTERED 
# USERNAME/PASSWORD COMBO IS 
# CORRECT!
################################

# GRAB THE USERNAME AND PASSWORD FROM THE POST
my $uName = param("uName");  
my $uPass = param("uPass");


# CHECK IF THESE PARAMETERS ARE CORRECT
my $status = checkUserPass($uName,$uPass);

# IF THE CREDENTIALS ARE CORRECT, PROCEED AS NORMAL
if ($status == 1)
{
    
################################
# OPEN THE HTML TEMPLATE AND 
# PRINT OUT THE INITIAL PART OF 
# THE HTML FILE
################################

# OPEN THE MAIN HTML CONTENTS FILE FOR THIS PAGE
    my $indexFile1 = 'templates/composite_index_part1.html';
    open (FILE,$indexFile1); 
    
# STORE THE CONTENTS OF THIS FILE IN A MATRIX
    @file = <FILE>;
    
# CLOSE THE FILE
    close (FILE);
    
# PRINT OUT EACH OF THE LINES IN THE FILE
    foreach $line (@file) {
	print "$line";
    }
    print "\n";
    
################################
# GET THE TIME LIMITS OF THE
# DATA ON THE MODEL SERVER
################################
    
# DEFINE THE MINIMUM/MAXIMUM DATE/TIME
    my $minYYYY='';  # MINIMUM YEAR
    my $minMM='';    # MINIMUM MONTH
    my $minDD='';    # MINIMUM DAY
    my $minHH='';    # MINIMUM HOUR
    
    my $maxYYYY='';  # MAXIMUM YEAR
    my $maxMM='';    # MAXIMUM MONTH
    my $maxDD='';    # MAXIMUM DAY
    my $maxHH='';    # MAXIMUM HOUR
    
# GET THE MINIMUM TIME OF THE GFS DATA
    ($minYYYY,$minMM,$minDD,$minHH)= &getGfsMinTime();
    
# GET THE MAXIMUM TIME OF THE GFS DATA
    ($maxYYYY,$maxMM,$maxDD,$maxHH)= &getGfsMaxTime();
    
    
    
################################
# PRINT OUT THE MONTH LIST
################################
    
    my $month=$minMM;  # MONTH INDEX
    my $printMonth=1;  # FLAG TO NOTE IF WE ARE TO PRINT THE MONTH
    my $counter=0;     # GENERIC COUNTER
    
    while ( $printMonth == "1" )  {
	
    # FORMAT THE OUTPUT WITH UP TO 2 LEADING ZEROS
	$month = sprintf("%02d", $month);
	
	# PRINT THE OPTION FOR THIS MONTH
	print " <option> $month </option>   \n" ;
	
	# IS THIS THE LAST MONTH OF THE YEAR?
	if ($month == 12) {
	    $month = 0;
	}
	
	# HAVE WE REACHED THE MAXIMUM MONTH?
	if ( $month == $maxMM ) {
	    $printMonth=0;
	}
	
	# HAVE WE REACHED THE MAXIMUM NUMBER OF 
	# MONTHS IN A YEAR?
	if ( $counter == 12 ) {
	    $printMonth=0;
	}
	
	# INCREMENT THE MONTH AND THE LOOP COUNTER
	$month++;
	$counter++;
    }
    
# PRINT MORE HTML CODE
print <<END_of_HTML;
    </select>
	</td>	  
	<td><b>/</b></td>
	<td align=center>  <select name="erupt_day">
END_of_HTML
	
	
################################
# PRINT OUT THE DAY LIST
################################

# GET THE LAST DAY OF THE MONTH FOR INPUTTED MONTH  
    my $lDay = `/usr/bin/perl getLastDay.pl $minYYYY $minMM`;
    
    my $month=$minMM;  # MONTH INDEX
    my $day=$minDD;    # DAY INDEX
    my $printDays=1;   # FLAG TO NOTE IF WE ARE TO PRINT THE MONTH
    my $counter=0;     # GENERIC COUNTER

    while ( $printDays == "1" ) {
	
	# FORMAT THE OUTPUT WITH UP TO 2 LEADING ZEROS
	$day = sprintf("%02d", $day);
	
	# PRINT OUT THE DAY
	print "<option> $day </option>    \n" ;
	
	# HAVE WE REACHED THE MAX DAY?
	if (( $day >= $maxDD ) && ( $month == $maxMM ))  {
	    $printDays=0;
	}
	
	# HAVE WE REACHED THE LAST DAY OF THE MONTH?
	if ( $day >= $lDay )  {
	    $day=0;
	    
	    #IS THIS THE LAST MONTH OF THE YEAR?
	    if ($month == 12) {
		$month = 01;
	    }
	    
	    # IF NOT, SIMPLY INCREMENT THE MONTH BY ONE
	    else {
		$month++;
	    }
	}
	
	# INCREMENT THE DAY NUMBER BY ONE
	$day++;
	
	# INCREMENT THE COUNTER
	$counter++;
	
	# DON'T CONTINUE PRINTING DAYS IF THE TOTAL NUMBER
	#   PRINTED DAYS EXCEEDS 32
	if ( $counter > 32 )   {
	    $printDays=0;
	}
    }
    
# PRINT MORE HTML CODE
print <<END_of_HTML;
		      </select>
		    </td>
 
		    <td><b>/</b></td>
		    <td align=center> <select name="erupt_year">
END_of_HTML


################################
# PRINT OUT THE YEAR LIST
################################

   for ( $year=$minYYYY; $year<=$maxYYYY; $year++ )  {
       print "<option> $year </option>   \n" ;
   }
    
    
################################
# PRINT OUT THE REMAINDER OF 
# THE HTML CODE FOR THIS TABLE
################################
    
print <<END_of_HTML;

		      </select>
		  </td> </tr>
 		</table>
	       </td>
  <tr> 
    
    <td  align=right>  Hour<b> : </b>Minute &nbsp;&nbsp</td>
         <td>
		   <table>
		     <td align=center>  <select name="erupt_hour">
                        <option> 00 </option>
			<option> 01 </option>
			<option> 02 </option>
			<option> 03 </option>
			<option> 04 </option>
			<option> 05 </option>
			<option> 06 </option>
			<option> 07 </option>
			<option> 08 </option>
			<option> 09 </option>
			<option> 10 </option>
			<option> 11 </option>
			<option> 12 </option>
			<option> 13 </option>
			<option> 14 </option>
			<option> 15 </option>
			<option> 16 </option>
			<option> 17 </option>
			<option> 18 </option>
			<option> 19 </option>
			<option> 20 </option>
			<option> 21 </option>
			<option> 22 </option>
			<option> 23 </option>
                        </select>
		      
		    <td><b>:</b></td>
		    <td align=center>  <select name="erupt_min">
			<option> 00 </option>		    
		       </select>
	       </td></tr>
	       </table>
   </td>
</tr>

<!--</table>
</td>
</tr>

<tr><td>  </td></tr>

-->

<tr><td> </td></tr>

	<tr>
	  <td width=165><b>  Eruption Duration:  </b></td>
	  <td> &nbsp;<input name="erupt_duration" class=time_textb type="Text" maxlength=2 > &nbsp;(hours)</input> </td>
	</tr>

      </table>
  </td></tr>
  
  <tr><td colspan=2> &nbsp; </td></tr>
  </table>


</td></tr>
</table>

</fieldset>

END_of_HTML


################################
# OPEN THE NEXT HTML TEMPLATE AND 
# PRINT OUT THE HTML FILE
################################

# OPEN THE MAIN HTML CONTENTS FILE FOR THIS PAGE
    my $indexFile1 = 'templates/composite_index_part2.html';
    open (FILE,$indexFile1); 

# STORE THE CONTENTS OF THIS FILE IN A MATRIX
    @file = <FILE>;
    
# CLOSE THE FILE
    close (FILE);
    
# PRINT OUT EACH OF THE LINES IN THE FILE
    foreach $line (@file) {
	print "$line";
    }
    print "\n";
    


    ###############################
    # GET THE LIMITS OF THE ORBIT
    # ORBIT DATA ON THE SERVER AND 
    # AND PRINT OUT THE RANGE
    ###############################

    # GET THE LIMITS OF THE ORBIT DATA
    $omiOrbitEnd = &getEndOrbit();
    $omiOrbitStart = &getStartOrbit();
        
    
    for ( $orbitNum=$omiOrbitEnd; $orbitNum<=$omiOrbitStart; $orbitNum++ ) {
	print "<option> $orbitNum </option>   \n";
    }
    
    # PRINT OUT MORE HTML CODE
    print <<END_of_HTML;
    </td>  </tr>

  <tr>
  <td><b> Product: </b></td>
  <td> <select name="product">
       <option> SO2 </option>
       <option> AI </option>
       </select>
  </td>
  </tr>
    
<tr><td>  </td></tr>
<tr><td>  </td></tr>

  <tr><td colspan=2>
      <table border=0>
        <tr>
	  <td colspan=2>
	    <table border=0>
	      <tr>
		<td width=200><b> Observation Date </b></td>
		<td  </td>
	      </tr>
  
  <tr>
    <td align=right>  Month<b> / </b>Day<b> / </b>Year &nbsp;&nbsp; </td>
    <td>  
      <table> 
	<tr>
	  <td align=center> <select name="obs_month">

END_of_HTML


    ################################
    # GET THE TIME LIMITS OF THE
    # DATA ON THE MODEL SERVER
    ################################

    # DEFINE THE MINIMUM/MAXIMUM DATE-TIME
    my $minYYYY='';  # MINIMUM YEAR
    my $minMM='';    # MINIMUM MONTH
    my $minDD='';    # MINIMUM DAY
    my $minHH='';    # MINIMUM HOUR

    my $maxYYYY='';  # MAXIMUM YEAR
    my $maxMM='';    # MAXIMUM MONTH
    my $maxDD='';    # MAXIMUM DAY
    my $maxHH='';    # MAXIMUM HOUR

    # GET THE MINIMUM GFS TIME
    ($minYYYY,$minMM,$minDD,$minHH)= &getGfsMinTime();

    # GET THE MAXIMUM GFS TIME
    ($maxYYYY,$maxMM,$maxDD,$maxHH)= &getGfsMaxTime();


    ################################
    # PRINT OUT THE MONTH LIST
    ################################

    my $month=$minMM;  # MONTH INDEX
    my $printMonth=1;  # FLAG TO NOTE IF WE ARE TO PRINT THE MONTH
    my $counter=0;     # GENERIC COUNTER
    
    while ( $printMonth == "1" )  {
	
	# FORMAT THE OUTPUT WITH UP TO 2 LEADING ZEROS
	$month = sprintf("%02d", $month);
	
	# PRINT THE OPTION FOR THIS MONTH
	print " <option> $month </option>   \n" ;
	
	# IS THIS THE LAST MONTH OF THE YEAR?
	if ($month == 12) {
	    $month = 0;
	}
	
	# HAVE WE REACHED THE MAXIMUM MONTH?
	if ( $month == $maxMM ) {
	    $printMonth=0;
	}
	
	# HAVE WE REACHED THE MAXIMUM NUMBER OF 
	# MONTHS IN A YEAR?
	if ( $counter == 12 ) {
	    $printMonth=0;
	}
	
	# INCREMENT THE MONTH AND THE LOOP COUNTER
	$month++;
	$counter++;
    }
    
    # PRINT MORE HTML CODE
print <<END_of_HTML;

	    </select>
	  </td>
	  
		    <td><b>/</b></td>
		    <td align=center>  <select name="obs_day">
END_of_HTML



    ################################
    # PRINT OUT THE DAY LIST
    ################################

    # GET THE LAST DAY OF THE MONTH FOR INPUTTED MONTH  
    my $lDay = `/usr/bin/perl getLastDay.pl $minYYYY $minMM`;

    
    my $month=$minMM;  # MONTH INDEX
    my $day=$minDD;    # DAY INDEX
    my $printDays=1;   # FLAG TO NOTE IF WE ARE TO PRINT THE MONTH
    my $counter=0;     # GENERIC COUNTER
    
    while ( $printDays == "1" ) {
	
	# FORMAT THE OUTPUT WITH UP TO 2 LEADING ZEROS
	$day = sprintf("%02d", $day);
	
	# PRINT OUT THE DAY
	print "<option> $day </option>    \n" ;
	
	# HAVE WE REACHED THE MAX DAY?
	if (( $day >= $maxDD ) && ( $month == $maxMM ))   {
	    $printDays=0;
	}
	
	# HAVE WE REACHED THE LAST DAY OF THE MONTH?
	if ( $day >= $lDay )  {
	    $day=0;

	    #IS THIS THE LAST MONTH OF THE YEAR?
	    if ($month == 12) {
		$month = 01;
	    }
	    else {
		$month++;
	    }
	}
	
	# INCREMENT THE DAY NUMBER BY ONE
	$day++;
	
	# INCREMENT THE COUNTER
	$counter++;
    
	# DON'T CONTINUE PRINTING DAYS IF THE TOTAL NUMBER
	#   PRINTED DAYS EXCEEDS 32
	if ( $counter > 32 )   {
	    $printDays=0;
	}
    }
    
# PRINT MORE HTML CODE
    print <<END_of_HTML;
    </select>
	</td>
	
	<td><b>/</b></td>
	<td align=center> <select name="obs_year">
END_of_HTML
	

       ################################
       # PRINT OUT THE YEAR LIST
       ################################
	
	for ( $year=$minYYYY; $year<=$maxYYYY; $year++ )  {
	    print "<option> $year </option>   \n" ;
	}
    
# PRINT OUT MORE HTML CODE
print <<END_of_HTML;

		      </select>
		  </td> </tr>
		</table>
	      </td>
  <tr>
    
    <td align=right>  Hour<b> : </b>Minute &nbsp;&nbsp</td>
    
    <td>
		  <table>
		    <td align=center>  <select name="obs_hour">
                        <option> 00 </option>
			<option> 01 </option>
			<option> 02 </option>
			<option> 03 </option>
			<option> 04 </option>
			<option> 05 </option>
			<option> 06 </option>
			<option> 07 </option>
			<option> 08 </option>
			<option> 09 </option>
			<option> 10 </option>
			<option> 11 </option>
			<option> 12 </option>
			<option> 13 </option>
			<option> 14 </option>
			<option> 15 </option>
			<option> 16 </option>
			<option> 17 </option>
			<option> 18 </option>
			<option> 19 </option>
			<option> 20 </option>
			<option> 21 </option>
			<option> 22 </option>
			<option> 23 </option>
		      </select>
		      
		    <td><b>:</b></td>
		    <td align=center>  <select name="obs_min">
			<option> 00 </option>		    
		      </select>
	      </td></tr>
	      </table>
  </td>
</tr>

<tr><td> </td></tr>

	<tr>
	  <td width=165><b>  DU Cutoff:  </b></td>
	  <td> &nbsp;<input name="duCtOff" class=time_textb type="Text" maxlength=3 > &nbsp;</input> </td>
	</tr>

      </table>
  </td></tr>


</table>
</td></tr>
</table>

</fieldset>
<br>
<br>

END_of_HTML


#############################################################
# WRITE INITIAL WEB PAGE
# TEMPLATE 
#############################################################
    
# OPEN THE MAIN HTML CONTENTS FILE FOR THIS PAGE 
    my $indexFile1 = 'templates/composite_index_part3.html';
    open (FILE,$indexFile1);
    
# STORE THE CONTENTS OF THIS FILE IN A MATRIX 
    @file = <FILE>;
    
# CLOSE THE FILE
    close (FILE);
    
    
# PRINT OUT EACH OF THE LINES IN THE FILE 
    foreach $line (@file) {
	print "$line";
    }
    

################################
# PRINT OUT THE REMAINDER OF 
# THE HTML CODE
################################

print <<END_of_HTML;

<table>
<tr>
<td align=center colspan=2><br> <button type=submit> Next >>> </button> </td>
<br>


</tr>
</table>
</form>

</center>


</body>
</html>



END_of_HTML

} elsif ( $status == 0 )
{
    # PRINT OUT A MESSAGE STATING THAT THE CREDENTIAL INFORMATION
    # GIVEN IS INCORRECT
    
    # PRINT OUT MORE HTML CODE
    print <<END_of_HTML;
<html>

<head>
  <title> PUFF Volcanic Height Analysis </title>
  <link rel="stylesheet" type="text/css" href="http://satepsanone.nesdis.noaa.gov/pub/OMI/PUFF/puffInputForm.css" />
</head>

<body>

"Invalid Username/Password"
<br><a href=http://satepsanone.nesdis.noaa.gov/pub/OMI/PUFF/volc3/login.html> Retry Login </a>

</body>
</html>

END_of_HTML


} else 
{
    # PRINT OUT A MESSAGE STATING THAT THE CREDENTIAL INFORMATION
    # GIVEN IS INCORRECT
    
    # PRINT OUT MORE HTML CODE
    print <<END_of_HTML;

<html>

<head>
  <title> PUFF Volcanic Height Analysis </title>
  <link rel="stylesheet" type="text/css" href="http://satepsanone.nesdis.noaa.gov/pub/OMI/PUFF/puffInputForm.css" />
</head>

<body>

"An error occured while attempting to log on, please contact support to report this problem"

</body>
</html>

END_of_HTML

}

