#!/usr/bin/perl -w

#==============================================================
# SCRIPT:       getJulDate.pl
#
# DESCRIPTION:  Convert the calendar date/time to julian 
#               date/time
#
# DEPENDENCIES: N/A
#
# INPUTS: YYYY:  Input year
#         MM:    Input month  
#         DD:    Input day
#         HH:    Input hour
#         MN:    Input minute
#               
# OUTPUTS:  jDate: Julian date
#
#============================================================== 


# RETRIEVE THE INPUTTED INFORMATION
$YYYY=$ARGV[0];  # YEAR
$MM=$ARGV[1];    # MONTH
$DD=$ARGV[2];    # DAY
$HH=$ARGV[3];    # HOUR
$MN=$ARGV[4];    # MINUTE

# CONVERT THE CALENDAR DATE TO A JULIAN DATE
$jDate=&date2jd($YYYY,$MM,$DD);

# CALCULATE THE HOURS AND MINS INTO THE FRACTIONAL AMOUNT OF A DAY
$dayHourFract=$HH/24;
$dayMinFract=$MN/(24*60);

$jDate=$jDate+$dayHourFract+$dayMinFract;

print $jDate;




#########################################################################


#==============================================================
# FUNCTION:     lastday
# DESCRIPTION:  USED TO COMPUTE THAT NUMBER OF DAYS IN A MONTH
#                  JULIAN DATE.
#
# INPUTS:  year:   A given year
#          month:  A given month
#               
# OUTPUTS:  feblength: The length of the a feburary leap year
#                      (no always an output)
#           mlength:   The length of the month (in days)
#
#==============================================================  
 sub lastday()  {

    # CONSTRUCT AN ARRAY OF "NUMBER OF DAYS IN EACH MONTH"
     $mlength[0]=00;   # xx
     $mlength[1]=31;   # January
     $mlength[2]=28;   # Feburary
     $mlength[3]=31;   # March
     $mlength[4]=30;   # April
     $mlength[5]=31;   # May
     $mlength[6]=30;   # June
     $mlength[7]=31;   # July
     $mlength[8]=31;   # August
     $mlength[9]=30;   # September
     $mlength[10]=31;  # October
     $mlength[11]=30;  # November
     $mlength[12]=31;  # December


     # GET THE INPUTTED YEAR
     $year=$_[0];
     
     # MAKE SURE THE YEAR IS WITHIN THE VALID JULIAN
     #   DATE RANGE
     if (( $year < 1860 || $year > 3999)) {
	 print "year out of range: $year.";
	 exit 1;
     }
     
     # GET THE INPUTTED MONTH
     $month=$_[1];
     
     # MAKE SURE THE MONTH IS VALID
     if (( $month < 1 || $month > 12 )) {
	 print "month out of range: $month.";
	 exit 1;
     }
     
     # IF WE'RE NOT DEALING WITH FEBURARY, THEN
     #   GET THE NUMBER OF DAYS FROM THE
     #   "NUMBER OF DAYS IN EACH MONTH" ARRAY
     if (($month != 2)) {
	 return "$mlength[$month] \n";
     }
     
     # SET A "IS LEAP YEAR?" VARIABLE INITIALLY TO ZERO (NO)
     $leap=0;
     
     # CHECK TO SEE IF THE INPUTTED YEAR IS A LEAP YEAR
     if ((!($year%100))) {
	 
	 if (!($year%400)) {
	     $leap=1;
	 }
     }
     else {
	 if (!($year%4)) {
	     $leap=1;
	 }
     }
 
     # DEFINE NUMBER OF DAYS IN FEBRUARY
     $feblength=28;
     
     # IF THE INPUTTED YEAR IS A LEAP YEAR, THEN 
     #   ADJUST THE LENGTH OF FEBURARY
     if ($leap) {
	 $feblength=29;	 
     }
     
     return "$feblength \n";
}


#==============================================================
# FUNCTION:     date2jd
# DESCRIPTION:  USED TO CONVERT A CALENDAR DATE TO A 
#                  JULIAN DATE.
#
# INPUTS:  year:  calendar year
#          month: calendar month
#          day:   calendar day
#
# OUTPUTS:  jd:  julian date
#============================================================== 
sub date2jd() {

    # RETRIEVE THE INPUTTED DATE INFO
    $year=$_[0];
    $month=$_[1];    
    $day=$_[2];


    # GET THE LAST DAY OF THE MONTH FOR INPUTTED MONTH
    $lday=&lastday($year, $month);

    
    # MAKE SURE THE INPUTTED DAY OF THE MONTH IS VALID
    if (( $day < 1  ||  $day > $lday ))  {
        print "day out of range";
        exit 1;
    }
    

    # COMPUTE THE JULIAN DATE
    $standard_jd = $day - 32075 + 1461 * ($year + 4800 - (14 - $month)/12)/4
	+ 367 * ($month - 2 + (14 - $month)/12*12)/12 - 
	3 * (($year + 4900 - (14 - $month)/12)/100)/4 ;
    $jd = $standard_jd-2400001;
    

    #TRUNCATE THE FINAL RESULT
    $jd=sprintf("%i", $jd);


    return $jd;
}



#########################################################################
