################################################################################
#-------------------------------------------------------------------------------
#  NAME:         getLogFile.pm
#
#  TYPE:         perl functions file
#
#  DESCRIPTION:  Contains many functions that are used to read and manipulate 
#                log files
#                #
#-------------------------------------------------------------------------------
################################################################################




#-------------------------------------------------------------------------------
#  FUNCTION:     getWaitingLog    
#
#  DESCRIPTION:  Retrieve the value in the waiting log
#                
#  INPUTS:       N/A
#
#  OUTPUTS:      $waitingLog:  The value in the waiting log
#
#-------------------------------------------------------------------------------
sub getWaitingLog {

    my $begunLogDir = `perl getPresets.pl logDir`;

    # EXTRACT THE VALUE FROM THE WAITING LOG
    my $waitingLog = `head -n1 $begunLogDir/waiting.log`;

    # IF NOTHING WAS FOUND, RETURN ERROR STATUS
    if ($waitingLog eq '') {$waitingLog=-1;}	

    return $waitingLog;
}

#-------------------------------------------------------------------------------
#  FUNCTION:     writeWaitingLog    
#
#  DESCRIPTION:  Write to the waiting log
#                
#  INPUTS:       $waitingLog:  The value to be written to the waiting log
#
#  OUTPUTS:      N/A
#
#-------------------------------------------------------------------------------
sub writeWaitingLog {

    # RETRIEVE THE VALUE TO WRITE TO THE WAITING LOG
    my $waitingLog = $_[0];
    
    # WRITE THIS VALUE TO THE WAITING LOG
    open(OUT, ">log/waiting.log") || die "Cannont open file";
    print OUT $waitingLog;
    close(OUT);
}

#-------------------------------------------------------------------------------
#  FUNCTION:     getBegunLog    
#
#  DESCRIPTION:  Retrieve the value in the begun log
#                
#  INPUTS:       N/A
#
#  OUTPUTS:      $begunLog:  The value in the begun log
#
#-------------------------------------------------------------------------------  
sub getBegunLog {
    
    # RETRIEVE THE SYSTEM OUTPUT DIR
    my $begunLogDir = `perl getPresets.pl dispDir`;

    # RETRIEVE THE 
    my $begunLog    = `head -n1  $begunLogDir/begun.log`;

    # SET AN ERROR STATUS IF WE COULDN'T OPEN THE FILE
    if (!($begunLog)) {$begunLog=-1;}

    return $begunLog;
}


#-------------------------------------------------------------------------------
#  FUNCTION:     getTransactionNum    
#
#  DESCRIPTION:  Retrieve the transaction number
#                
#  INPUTS:       N/A
#
#  OUTPUTS:      $transactionNum:  The transaction number
#
#------------------------------------------------------------------------------- 
sub getTransactionNum {

    # RETRIEVE THE TRANSACTION NUMBER
    my $transactionNum = `head -n1 log/transaction_num.log`;

    # SET AN ERROR STATUS IF WE COULDN'T OPEN THE FILE
    if ($transactionNum eq '') {$transactionNum=-1;}	

    return $transactionNum;
}


#-------------------------------------------------------------------------------
#  FUNCTION:     writeTransactionNum    
#
#  DESCRIPTION:  Write to the transaction number log
#                
#  INPUTS:       $processNum: The transaction number
#
#  OUTPUTS:     
#
#------------------------------------------------------------------------------- 
sub writeTransactionNum {

    # RETRIEVE THE TRANSACTION NUMBER
    my $processNum = $_[0];

    # WRITE THE TRANSACTION NUMBER TO THE LOG FILE
    open(OUT, ">log/transaction_num.log") || die "Cannont open file";
    print OUT $processNum;
    close(OUT);
}


#-------------------------------------------------------------------------------
#  FUNCTION:     getCheckTime    
#
#  DESCRIPTION:  Retrieve the time from the checkTime log file
#                
#  INPUTS:       N/A
#
#  OUTPUTS:      $checkTime:  The time in the log file
#
#------------------------------------------------------------------------------- 
sub getCheckTime {

    # RETRIEVE THE SYSTEM OUTPUT DIR
    my $checkTimeDir = `perl getPresets.pl dispDir`;

    # RETRIEVE THE VALUE IN THE CHECK TIME LOG FILE
    my $checkTime = `head -n1 $checkTimeDir/checkTime.log`;

    # SET AN ERROR STATUS IF THE FILE FAILED TO OPEN
    if ($checkTime eq '') {$checkTime=-1;}	

    return $checkTime;
}


#-------------------------------------------------------------------------------
#  FUNCTION:     getGfsMinTime    
#
#  DESCRIPTION:  Retrieve the time from the gfsMinTime log file
#                
#  INPUTS:       N/A
#
#  OUTPUTS:      $minYYYY:  Year
#                $minMM:    Month
#                $minDD:    Day
#                $minHH:    Hour
#
#------------------------------------------------------------------------------- 
sub getGfsMinTime {

    # RETRIEVE THE SYSTEM OUTPUT DIR
    my $gfsTimeDir = `perl getPresets.pl dispDir`;

    $minTime = `head -n1 $gfsTimeDir/gfsTimeRange.log`;

    # EXTRACT THE INDIVIDUAL DATE/TIME ELEMENTS
    my $minYYYY = substr($minTime,0,4);
    my $minMM   = substr($minTime,4,2);
    my $minDD   = substr($minTime,6,2);
    my $minHH   = substr($minTime,8,2);

    return $minYYYY,$minMM,$minDD,$minHH;
}


#-------------------------------------------------------------------------------
#  FUNCTION:     getGfsMaxTime    
#
#  DESCRIPTION:  Retrieve the time from the gfsMaxTime log file
#                
#  INPUTS:       N/A
#
#  OUTPUTS:      $maxYYYY:  Year
#                $maxMM:    Month
#                $maxDD:    Day
#                $maxHH:    Hour
#
#------------------------------------------------------------------------------- 
sub getGfsMaxTime {

    # RETRIEVE THE SYSTEM OUTPUT DIR
    my $gfsTimeDir = `perl getPresets.pl dispDir`;

    my $maxTime = `tail -n1 $gfsTimeDir/gfsTimeRange.log`;

    # EXTRACT THE INDIVIDUAL DATE/TIME ELEMENTS
    my $maxYYYY = substr($maxTime,0,4);
    my $maxMM   = substr($maxTime,4,2);
    my $maxDD   = substr($maxTime,6,2);
    my $maxHH   = substr($maxTime,8,2);

    return $maxYYYY,$maxMM,$maxDD,$maxHH;
}


#-------------------------------------------------------------------------------
#  FUNCTION:     getStartOrbit    
#
#  DESCRIPTION:  Retrieve the start orbit from the orbit log file
#                
#  INPUTS:       N/A
#
#  OUTPUTS:      $startOrbit:  The starting (oldest) orbit 
#
#------------------------------------------------------------------------------- 
sub getStartOrbit {

    # RETRIEVE THE SYSTEM OUTPUT DIR
    my $orbitDir = `perl getPresets.pl dispDir`;

    # RETRIEVE THE START ORBIT
    my $startOrbit = `tail -n1 $orbitDir/omiOrbitRange.log`;

    # SET AN ERROR STATUS IF THE FILE FAILS TO OPEN
    if (!($startOrbit)) {$startOrbit=-1;}

    return $startOrbit;
}


#-------------------------------------------------------------------------------
#  FUNCTION:     getEndOrbit    
#
#  DESCRIPTION:  Retrieve the end orbit from the orbit log file
#                
#  INPUTS:       N/A
#
#  OUTPUTS:     $endOrbit: The  ending (newest) orbit
#
#------------------------------------------------------------------------------- 
sub getEndOrbit {

    # RETRIEVE THE SYSTEM OUTPUT DIR
    my $orbitDir = `perl getPresets.pl dispDir`;

    # RETRIEVE THE END ORBIT
    my $endOrbit = `head -n1 $orbitDir/omiOrbitRange.log`; 

    # SET AN ERROR STATUS IF THE FILE FAILS TO OPEN
    if (!($endOrbit)) {$endOrbit=-1;}

    return $endOrbit;
}


#-------------------------------------------------------------------------------
#  FUNCTION:     getDispDir    
#
#  DESCRIPTION:  Retrieve the directory containing the system output
#                
#  INPUTS:       N/A
#
#  OUTPUTS:      $dispDir:  The directory containing the system output
#
#------------------------------------------------------------------------------- 
sub getDispDir {

    # RETRIEVE THE SYSTEM OUTPUT DIRECTORY
    my $dispDir = `perl getPresets.pl dispDir`;

    return $dispDir;
}


#-------------------------------------------------------------------------------
#  FUNCTION:     getWebOutputDir    
#
#  DESCRIPTION:  Retrieve the web-accessable directory path containing the 
#                system output
#                
#  INPUTS:       N/A
#
#  OUTPUTS:      $webDir:  The web-directory containing the system output
#
#------------------------------------------------------------------------------- 
sub getWebOutputDir {

    # RETRIEVE THE SYSTEM OUTPUT DIRECTORY
    my $webDir = `perl getPresets.pl webDir`;

    return $webDir;
}


#-------------------------------------------------------------------------------
#  FUNCTION:     getCgiDir    
#
#  DESCRIPTION:  Retrieve the web-accessable directory path containing the 
#                cgi scripts
#                
#  INPUTS:       N/A
#
#  OUTPUTS:      $cgiDir:  The web-directory containing the cgi scripts
#
#------------------------------------------------------------------------------- 
sub getCgiDir {

    # RETRIEVE THE SYSTEM OUTPUT DIRECTORY
    my $cgiDir = `perl getPresets.pl cgiDir`;

    return $cgiDir;
}


#-------------------------------------------------------------------------------
#  FUNCTION:     checkUserPass
#
#  DESCRIPTION:  Check/verify the password for a given user
#
#  INPUTS:       $uName:    The username for the given request
#                $uPass:    The password for the given request
#
#  OUTPUTS:      $status:  Boolean value to denote if the inputs are correct
#
#-------------------------------------------------------------------------------
sub checkUserPass {

    # RETRIEVE INPUTS FROM THE USER
    my $uName = $_[0];
    my $uPass = $_[1];

    #  THE USERNAME LOG FILE
    my $userLog="log/$uName.log";

    # SET THE INITIAL STATUS TO FALSE.
    my $status = 0;
    
    # IF THE LOG FILE EXISTS, THEN CHECK THE
    # USERNAME/PASSWORD
    if (-e $userLog)
    {
	# GET THE ACUTAL PASSWORD FOR THIS USER
	my $uPassReal = `head -n1 $userLog`;
	
	# MAKE SURE WE REMOVE THE NEWLINE CHARACTER
	chomp($uPassReal);
	
	# DOES THE USER INPUTTED PASSWORD MATCH THE
	# THE ACTUAL PASSWORD
	if ($uPass eq $uPassReal)
	{
	    # DENOTE THAT THE GIVEN PASSWORD IS CORRECT
	    $status=1;
	}
    }

    return $status

}




1;
