#!/usr/bin/perl -w

################################################################################
#-------------------------------------------------------------------------------
#  NAME:         getPresets.pl
#
#  TYPE:         perl Script
#
#  DESCRIPTION:  Reads a presets.dat file and extract the value for a 
#                desired variable name.
#
#  DEPENDENCES:  presets.dat
#
#  INPUTS:       $desiredVar: Name of the variable that we are searching for
#
#  OUTPUTS:      $value:      The value for the desired variable, that was
#                             found in the presets.dat file
#
#  HISTORY:
#
#
#-------------------------------------------------------------------------------
################################################################################

# RETRIEVE THE NAME OF THE VARIABLE THAT WE
#  WANT TO SEARCH FOR
$desiredVar=$ARGV[0];

# OPEN THE MAIN HTML CONTENTS FILE FOR THIS PAGE
my $presetsFile = 'presets.dat';
open (DATAFILE,$presetsFile); 

# BY DEFAULT, SET THE OUTPUT VALUE TO "-1"
my $value = "-1";


# SEARCH THROUGH THE FILE, LINE BY LINE
while (defined ($line = <DATAFILE>)) {

    # REMOVE THE NEW-LINE CHARACTER
    chomp $line;

    # LOOK FOR THE COMMENT SYMBOL?
    $commentLocation = index( $line, "#");


    # REMOVE ANY COMMENTS IN THE LINE, IF NECESSARY
    if ( $commentLocation > -1 )
    {
	# EXTRACT EVERYTHING TO THE LEFT OF THE 
	#  COMMENT SYMBOL
	$subLine = substr( $line, 0, $commentLocation);
    }
    else 
    {
	# THERE ARE NO COMMENTS ON THIS LINE, SO
	# USE THE ENTIRE LINE
	$subLine=$line;
    }

    # LENGTH OF THE SUBSTRING
    $size = length($subLine);
    

    # IS THERE ANYTHING ON THIS LINE?
    if ($size > 0)
    {	
	# DOES THIS LINE CONTAIN A VARIABLE
	$assignLocation = index( $line, "=");


	# IF YES, THEN GET THE VARIABLE NAME
	if ($assignLocation > -1)
	{
	    # EXTRACT THE VARIABLE NAME
	    $varName = substr( $subLine, 0, $assignLocation);
	

	    # IS THIS THE VARIABLE NAME THAT WE'RE LOOKING FOR?
	    if ($varName eq $desiredVar)
	    {

		# IT IS! SO GET THE VARIABLE VALUE
		$value = substr($subLine, $assignLocation+1, $size-1);
	    }   
	}
    }   
}


# OUTPUT THE VARIABLE NAME
print "$value";


exit








