#!/usr/bin/perl -w


################################################################################
#-------------------------------------------------------------------------------
#  NAME:         showSim.pl
# 
#  TYPE:         perl Script 
#
#  DESCRIPTION:  Show the requested simulation image.
#                
#  DEPENDENCES:  getLogFile.pm     
#     
#  INPUTS:       N/A
#      
#  OUTPUTS:      N/A
#
#  HISTORY:
# 
#-------------------------------------------------------------------------------
################################################################################

# SET FOR USAGE WITH THE CGI-BIN
use CGI;
use CGI::Carp qw(warningsToBrowser fatalsToBrowser); 
use CGI qw(:standard);

# RETRIEVE A SET OF FUNCTIONS USED TO READ AND WRITE TO 
# LOG FILES
require "getLogFile.pm";

# DIRECTORY DEFINITIONS
my $sate_puff_dir = getDispDir();
my $results_dir = $sate_puff_dir.'/processedRuns';

# DEFINE THE WEB-BASED SYSTEM OUTPUT DIRECTORY
my $web_dir = getWebOutputDir();
my $web_results_dir="http://satepsanone.nesdis.noaa.gov/$web_dir/processedRuns";

# RETRIEVE VARIABLES FROM THE 'GET'
my $processNum = param("processNum");
my $height = param("height");

# GET THE PROFILE PLOT
my $heightProfile = "$web_results_dir/${processNum}_heightProfile.png" ;

# SEARCH FOR THE SELECTED SIMULATION TO DISPLAY
my @files = < $results_dir/${processNum}_sim_*${height}km.png>;

# GET THE FILENAME FROM THE FULL PATH NAME
my @fullName = split('/',$files[$#files]);
my $dispSim = "$web_results_dir/$fullName[$#fullName]";


# PRINT OUT THE WEBSITE INITIAL INFO
print "Content-type: text/html\n\n";
print "<html>";
print "<body>";

print "<center>";
print "<table border=1 cellpadding=5>";
print "<tr><td align=center>";
print "    <table border=0>";
print "      <tr><td>";

print "      <img src=$dispSim ></img><br>" ;	     
print "	     Simulation Base Height: $height km";
print "	     </td></tr>";
print "	     <tr><td>";
print "	     <br> <br>";
print "	     <img src=$heightProfile height=301 width=396 ></img>";
	  
print "      </td></tr>";
print "    </table>";
print "</td>";
print "<td>";

# INITIALIZE ARRAYS
my @fNames = ();
my @fProcess = ();
my @volcano = ();
my @height = ();
my @order = ();
my @tNames = ();

# GET A DIRECTORY LISTING FOR THE IMAGE OUTPUT DIRECTORY
my $counter = 0;
my @files = < $results_dir/${processNum}_sim_*.png>;
foreach $file (@files) {
   
    # GET THE FILENAME FROM THE FULL PATH NAME
    my @fullName = split('/',$file);
    my $fName = $fullName[$#fullName];
    push(@fNames, $fName);
    
    # EXTRACT INFORMATION FROM THE FILENAME
    my @fileInfo = split('_',$fName);
    
    # EXTRACT OUT THE PROCESSING NUMBER
    push(@fProcess, $fileInfo[0]);
    
    # EXTRACT OUT THE VOLCANO NAME
    push(@volcano, $fileInfo[2]);
    
    # EXTRACT OUT THE NUMERICAL HEIGHT
    my @fHeight = split('km',$fileInfo[3]);
    push(@height, $fHeight[0]);

    # KEEP TRACK OF THE INDEX ORDER
    push(@order, $counter);
    $counter++;
} 

# SAVE THE ARRAY LENGTH
my $arrayLen = $counter;

# GET A DIRECTORY LISTING FOR THE IMAGE OUTPUT THUMBNAILS
my @files = < $results_dir/${processNum}_simThumb_*.png>;
foreach $file (@files) {
   
    # GET THE FILENAME FROM THE FULL PATH NAME
    my @fullName = split('/',$file);
    my $fName = $fullName[$#fullName];
    push(@tNames, $fName);
} 


# GET A SORTED ARRAY INDEX, BASED ON THE HEIGHT (lowest -> highest)
my @sortedHeight = sort(@height);
my @sortedfNames = sort(@fNames);
my @sortedtNames = sort(@tNames);




# COMPUTE THE TOTAL NUMBER OF ROWS AND COLUMNS TO BE IN OUR TABLE
my $nCols = 3;
$nCols = $nCols-1;
my $nImages = $arrayLen + 1;
my $nRows = int($nImages / $nCols)+1;

# PRINT OUT THE TABLE
print "<td valign=top>";
print "<center>";
print "<table border=1>";
print "<b> PUFF Simulations </b>";

# ITERATE THROUGH EACH OF THE TABLE ELEMENTS TO BE WRITTEN
$counter=0;
for ($i=0; $i<=$nRows; $i++)
{
	print "<tr>";
	for ($j=0; $j<=$nCols; $j++)
	{
		print "<td>";	
	
		if ($counter < $nImages-1)
		{
		    # PRINT OUT THE HEIGHT
		    print "$sortedHeight[$counter] km <br>";

		    # CHREATE A LINK TO THE SIMULATION IMAGE
		    print "<a href=showSim.pl?processNum=$processNum&height=$sortedHeight[$counter]>";

		    # PRINT AN IMAGE THUMBNAIL OF THE SIMULATION 
		    print "<img src=$web_results_dir/$sortedtNames[$counter]></img>";
		    print "</a>";

		    $counter++;
		}
		print "</td>";
	    }    
	print "</tr>";	
}

# FINISH PRINTING OUT THE TABLE
print "</table>";
print "</center>";
print "</td>";
print "</tr>";
print "</table>";

# FINISH PRINTING OUT THE HTML PAGE ELEMENTS
print "</body>";
print "</html>";




