#!/usr/bin/perl -w

################################################################################
#-------------------------------------------------------------------------------
#  NAME:         submitRequest.pl
# 
#  TYPE:         perl Script 
#
#  DESCRIPTION:  Output the user inputs to a data file and get a transaction
#                number
#
#  DEPENDENCES:  getLogFile.pm     
#     
#  INPUTS:       $volcano:         Name for volcano that erupted
#                $erupt_year:      Year of the eruption 
#                $erupt_month:     Month of the eruption 
#                $erupt_day:       Day of the eruption
#                $erupt_hour:      Hour of the eruption 
#                $erupt_min:       Minute of the eruption 
#                $erupt_duration:  The duration of the eruption    
#                $sensor:          Sensor data being used
#                $orbit_number     Satellite data orbital number  
#                $product          Type of product being used
#                $obs_year         Observation year
#                $obs_month        Observation month
#                $obs_day          Observation day
#                $obs_hour         Observation hour
#                $obs_min          Observation minute
#                $duCtOff          Threshold cut-off value for satellite data
#      
#  OUTPUTS:      $puffRun_#.dat    A data file containing the user inputs, the
#                                   transaction number is used in the filename
#                                   in the place of #
#
#  HISTORY:
# 
#
#-------------------------------------------------------------------------------
################################################################################


# SET FOR USAGE WITH THE CGI-BIN
use CGI;
use CGI::Carp qw(warningsToBrowser fatalsToBrowser); 
use CGI qw(:standard);

# RETRIEVE A SET OF FUNCTIONS USED TO READ AND WRITE TO 
# LOG FILES
require "getLogFile.pm";

# DEFINE THE WEB-BASED SYSTEM OUTPUT DIRECTORY
my $cgi_dir = getCgiDir();

################################
# MAKE SURE THE SYSTEM IS NOT
# ALREADY PROCESSING ANOTHER 
# REQUEST
################################

# CHECK TO SEE IF ANOTHER PROCESS IS WAITING TO BE RUN
my $waiting4Puff = &getWaitingLog();

# CHECK TO SEE IF ANOTHER PROCESS IS CURRENTLY BEING RUN
my $waiting2Finish = &getBegunLog();

# IF NO OTHER PROCESS ARE CURRENTLY, OR WAITING TO, BE RUN THEN 
#   ALLOW THE USER TO CONTINUE
if ($waiting4Puff == 0)
{
    if ($waiting2Finish == 0)
    {

	# SET THE WAITING LOG FILE TO INDICATE THAT A PROCESS IS
	# IS WAITING TO BE RUN 
	&writeWaitingLog("1");


	# RETRIEVE VARIABLES FROM THE 'GET'
	my $volcano        = param("volcano");         # NAME OF VOLCANO
	my $erupt_year     = param("erupt_year");      # ERUPTION YEAR
	my $erupt_month    = param("erupt_month");     # ERUPTION MONTH
	my $erupt_day      = param("erupt_day");       # ERUPTION DAY
	my $erupt_hour     = param("erupt_hour");      # ERUPTION HOUR
	my $erupt_min      = param("erupt_min");       # ERUPTION MINUTE
	my $erupt_duration = param("erupt_duration");  # DURATION OF THE ERUPTION
	my $sensor         = param("sensor");          # NAME OF THE SATELLITE SENSOR USED
	my $orbit_number   = param("orbit_number");    # SATELLITE DATA ORBITAL NUMBER
	my $product        = param("product");         # DATA PRODUCT USED
	my $obs_year       = param("obs_year");        # OBSERVATION YEAR
	my $obs_month      = param("obs_month");       # OBSERVATION MONTH
	my $obs_day        = param("obs_day");         # OBSERVATION DAY
	my $obs_hour       = param("obs_hour");        # OBSERVATION HOUR
	my $obs_min        = param("obs_min");         # OBSERVATION MINUTE
	my $duCtOff        = param("duCtOff");         # SATELLITE DATA THRESHOLD VALUE
	my $metModel       = param("metModel");        # METEROLOGICAL MODEL USED
	my $hiLat          = param("hiLat");           # MAPPING LIMIT: UPPER LATITUDE
	my $lowLat         = param("lowLat");          # MAPPING LIMIT: LOWER LATITUDE
	my $hiLon          = param("hiLon");           # MAPPING LIMIT: HIGHER LONGITUDE
	my $lowLon         = param("lowLon");          # MAPPING LIMIT: LOWER LONGITUDE
	

	# GET THE CURRENT PREVIOUS TRANSACTION NUMBER AND INCREMENT IT
	# BY ONE FOR THIS TRANSACTION.
	my $processNum = &getTransactionNum;
	$processNum++;
	
	# SAVE THIS TRANSACTION NUMBER TO THE LOG FILE
	&writeTransactionNum($processNum);
	
	################################
        # WRITE THE USER INPUT TO A 
        # DATA FILE
        ################################
	
	# THE FILENAME FOR THE PROCESS INITIALIZATION FILE
	$puffFile="inputFiles/puffRun_".$processNum.".dat";
	
	# WRITE THE INPUTTED VARIABLES TO THE INITIALIZATION FILE
	open(PUFF_OUT, ">".$puffFile) || die "Cannont open file:  ".$puffFile;
	print PUFF_OUT    "$volcano         \n" ;
	print PUFF_OUT    "$erupt_year      \n";
	print PUFF_OUT    "$erupt_month     \n";
	print PUFF_OUT    "$erupt_day       \n";
	print PUFF_OUT    "$erupt_hour      \n";
	print PUFF_OUT    "$erupt_min       \n";
	print PUFF_OUT    "$erupt_duration  \n";
	print PUFF_OUT    "$sensor          \n";
        print PUFF_OUT    "$orbit_number    \n"; 
        print PUFF_OUT    "$obs_year        \n";
        print PUFF_OUT    "$obs_month       \n"; 
        print PUFF_OUT    "$obs_day         \n"; 
        print PUFF_OUT    "$obs_hour        \n"; 
        print PUFF_OUT    "$obs_min         \n";
	print PUFF_OUT    "$sensor          \n";
	print PUFF_OUT    "$metModel        \n";
	print PUFF_OUT    "$hiLat           \n";
	print PUFF_OUT    "$lowLat          \n";
	print PUFF_OUT    "$hiLon           \n";
	print PUFF_OUT    "$lowLon          \n";
	print PUFF_OUT    "$duCtOff         \n";
	print PUFF_OUT    "$processNum      \n";
	print PUFF_OUT    "$product         \n";
	close(PUFF_OUT);

	# RE-DIRECT THE USER TO THE WAITING SCREEN
	print "Location: http://satepsanone.nesdis.noaa.gov/$cgi_dir/wait4Pickup.pl?processNum=".$processNum."\n\n";	
    }
    else {
 
	# ANOTHER PROCESS IS CURRENTLY BEING RUN ON THE MACHINE, ADVICE THE USER TO 
	# TRY AND RUN THEIR PROCESS LATER.
	
	print "Content-type: text/html\n\n";
	
	print "<html>";
	print "<body>";
	
	print "<center>";
	print "Another simulation is corrently being processed, please try again in a few minutes ...";
	print "</center>";
	print "</body>";
	print "</html>";
	
    }	
} else {
    
    # ANOTHER PROCESS IS CURRENTLY BEING RUN ON THE MACHINE, ADVICE THE USER TO 
    # TRY AND RUN THEIR PROCESS LATER.
    
    print "Content-type: text/html\n\n";
    
    print "<html>";
    print "<body>";
    
    print "<center>";
    print "Another simulation is corrently being processed, please try again in a few minutes ...";
    print "</center>";
    print "</body>";
    print "</html>";
    
}



